pub fn read_file<P: AsRef<Path>>(path: P) -> Result<Save, ParseError>Expand description
The only entry point to this library. Given a Path or something that can be converted into one, attempts to read the file at that path and then reads its various components byte-by-byte to build up its own representation of the data within